@@ -7,6 +7,7 @@
 #include <QQmlEngine>
 
 #include <kauthorized.h>
+#include <kcoreconfigskeleton.h>
 
 struct KAuthorizedForeign {
     Q_GADGET
@@ -15,4 +16,10 @@ struct KAuthorizedForeign {
     QML_FOREIGN(KAuthorized)
 };
 
+struct KCoreConfigSkeletonForeign {
+    Q_GADGET
+    QML_ANONYMOUS
+    QML_FOREIGN(KCoreConfigSkeleton)
+};
+
 #endif
